@@ -15,7 +15,7 @@ from utilities.re import ExtractGroupError, extract_group
 from utilities.whenever import MINUTE, get_now_local_plain
 
 if TYPE_CHECKING:
-    from collections.abc import AsyncIterator, Iterator, Sequence
+    from collections.abc import AsyncIterator, Iterator
     from pathlib import Path
 
     from _pytest.fixtures import SubRequest
@@ -99,7 +99,7 @@ def test_engine(*, request: SubRequest, tmp_path: Path) -> Engine:
             )
             try:
                 with engine.begin() as conn:
-                    tables: Sequence[str] = (
+                    tables: list[str] = list(
                         conn.execute(_select_tables()).scalars().all()
                     )
             except OperationalError:
@@ -157,7 +157,7 @@ async def test_async_postgres_engine() -> AsyncEngine:
     )
     try:
         async with engine.begin() as conn:
-            tables: Sequence[str] = (
+            tables: list[str] = list(
                 (await conn.execute(_select_tables())).scalars().all()
             )
     except InvalidCatalogNameError:
@@ -176,7 +176,7 @@ def _is_to_drop(table: str, /) -> bool:
         text = extract_group(r"^(\d{8}T\d{2,})_", table)
     except ExtractGroupError:
         return True
-    date_time = PlainDateTime.parse_common_iso(text)
+    date_time = PlainDateTime.parse_iso(text)
     age = now.difference(date_time, ignore_dst=True)
     return age >= MINUTE
 
