@@ -179,7 +179,7 @@ class TestAssumeDoesNotRaise:
         if x is True:
             with (
                 raises(ValueError, match=msg),
-                assume_does_not_raise(ValueError, match="wrong"),
+                assume_does_not_raise(ValueError, match=r"wrong"),
             ):
                 raise ValueError(msg)
 
@@ -209,7 +209,7 @@ class TestDateDeltas:
         if max_value is not None:
             assert days <= to_days(max_value)
         if parsable:
-            assert DateDelta.parse_common_iso(delta.format_common_iso()) == delta
+            assert DateDelta.parse_iso(delta.format_iso()) == delta
 
 
 class TestDatePeriods:
@@ -247,7 +247,7 @@ class TestDateTimeDeltas:
         if max_value is not None:
             assert nanos <= to_nanoseconds(max_value)
         if parsable:
-            assert DateTimeDelta.parse_common_iso(delta.format_common_iso()) == delta
+            assert DateTimeDelta.parse_iso(delta.format_iso()) == delta
         if nativable:
             assert isinstance(to_py_time_delta(delta), dt.timedelta)
 
@@ -262,7 +262,7 @@ class TestDates:
                 dates(min_value=min_value, max_value=max_value, two_digit=two_digit)
             )
         assert isinstance(date, Date)
-        assert Date.parse_common_iso(date.format_common_iso()) == date
+        assert Date.parse_iso(date.format_iso()) == date
         if min_value is not None:
             assert date >= min_value
         if max_value is not None:
@@ -332,7 +332,7 @@ class TestDraw2:
 
         with raises(
             _Draw2InputResolvedToSentinelError,
-            match="The input resolved to the sentinel value; a default strategy is needed",
+            match=r"The input resolved to the sentinel value; a default strategy is needed",
         ):
             _ = data.draw(strategy())
 
@@ -346,7 +346,7 @@ class TestDraw2:
 
         with raises(
             _Draw2InputResolvedToSentinelError,
-            match="The input resolved to the sentinel value; a default strategy is needed",
+            match=r"The input resolved to the sentinel value; a default strategy is needed",
         ):
             _ = data.draw(strategy())
 
@@ -361,7 +361,7 @@ class TestDraw2:
 
         with raises(
             _Draw2DefaultGeneratedSentinelError,
-            match="The default search strategy generated the sentinel value",
+            match=r"The default search strategy generated the sentinel value",
         ):
             _ = data.draw(strategy())
 
@@ -375,7 +375,7 @@ class TestDraw2:
 
         with raises(
             _Draw2DefaultGeneratedSentinelError,
-            match="The default search strategy generated the sentinel value",
+            match=r"The default search strategy generated the sentinel value",
         ):
             _ = data.draw(strategy())
 
@@ -722,7 +722,7 @@ class TestMonthDays:
         with assume_does_not_raise(InvalidArgument):
             month_day = data.draw(month_days(min_value=min_value, max_value=max_value))
         assert isinstance(month_day, MonthDay)
-        assert MonthDay.parse_common_iso(month_day.format_common_iso()) == month_day
+        assert MonthDay.parse_iso(month_day.format_iso()) == month_day
         if min_value is not None:
             assert month_day >= min_value
         if max_value is not None:
@@ -760,10 +760,11 @@ class TestPairs:
 
 
 class TestPaths:
-    @given(data=data())
-    def test_main(self, *, data: DataObject) -> None:
-        min_depth = data.draw(integers(0, 3) | none())
-        max_depth = data.draw(integers(0, 3) | none())
+    @given(data=data(), depths=pairs(integers(0, 3) | none()))
+    def test_main(
+        self, *, data: DataObject, depths: tuple[int | None, int | None]
+    ) -> None:
+        min_depth, max_depth = depths
         with assume_does_not_raise(InvalidArgument):
             path = data.draw(paths(min_depth=min_depth, max_depth=max_depth))
         assert isinstance(path, Path)
@@ -785,7 +786,7 @@ class TestPlainDateTimes:
                 plain_date_times(min_value=min_value, max_value=max_value)
             )
         assert isinstance(datetime, PlainDateTime)
-        assert PlainDateTime.parse_common_iso(datetime.format_common_iso()) == datetime
+        assert PlainDateTime.parse_iso(datetime.format_iso()) == datetime
         if min_value is not None:
             assert datetime >= min_value
         if max_value is not None:
@@ -1036,7 +1037,7 @@ class TestTimeDeltas:
         with assume_does_not_raise(InvalidArgument):
             delta = data.draw(time_deltas(min_value=min_value, max_value=max_value))
         assert isinstance(delta, TimeDelta)
-        assert TimeDelta.parse_common_iso(delta.format_common_iso()) == delta
+        assert TimeDelta.parse_iso(delta.format_iso()) == delta
         assert isinstance(to_py_time_delta(delta), dt.timedelta)
         if min_value is not None:
             assert delta >= min_value
@@ -1066,7 +1067,7 @@ class TestTimes:
         with assume_does_not_raise(InvalidArgument):
             time = data.draw(times(min_value=min_value, max_value=max_value))
         assert isinstance(time, Time)
-        assert Time.parse_common_iso(time.format_common_iso()) == time
+        assert Time.parse_iso(time.format_iso()) == time
         if min_value is not None:
             assert time >= min_value
         if max_value is not None:
@@ -1203,7 +1204,7 @@ class TestYearMonths:
                 )
             )
         assert isinstance(year_month, YearMonth)
-        assert YearMonth.parse_common_iso(year_month.format_common_iso()) == year_month
+        assert YearMonth.parse_iso(year_month.format_iso()) == year_month
         if min_value is not None:
             assert year_month >= min_value
         if max_value is not None:
@@ -1257,7 +1258,7 @@ class TestZonedDateTimes:
             )
         assert isinstance(datetime, ZonedDateTime)
         _ = datetime.py_datetime()
-        assert ZonedDateTime.parse_common_iso(datetime.format_common_iso()) == datetime
+        assert ZonedDateTime.parse_iso(datetime.format_iso()) == datetime
         assert datetime.tz == time_zone.key
         if min_value is not None:
             assert datetime >= min_value
