@@ -255,7 +255,7 @@ class TestCheckBijection:
     def test_error(self) -> None:
         with raises(
             CheckBijectionError,
-            match="Mapping .* must be a bijection; got duplicates {None: 2}",
+            match=r"Mapping .* must be a bijection; got duplicates {None: 2}",
         ):
             check_bijection({True: None, False: None})
 
@@ -268,7 +268,7 @@ class TestCheckDuplicates:
     def test_error(self) -> None:
         with raises(
             CheckDuplicatesError,
-            match="Iterable .* must not contain duplicates; got {None: 2}",
+            match=r"Iterable .* must not contain duplicates; got {None: 2}",
         ):
             check_duplicates([None, None])
 
@@ -280,35 +280,35 @@ class TestCheckIterablesEqual:
     def test_error_differing_items_and_left_longer(self) -> None:
         with raises(
             CheckIterablesEqualError,
-            match="Iterables .* and .* must be equal; differing items were .* and left was longer",
+            match=r"Iterables .* and .* must be equal; differing items were .* and left was longer",
         ):
             check_iterables_equal([1, 2, 3], [9])
 
     def test_error_differing_items_and_right_longer(self) -> None:
         with raises(
             CheckIterablesEqualError,
-            match="Iterables .* and .* must be equal; differing items were .* and right was longer",
+            match=r"Iterables .* and .* must be equal; differing items were .* and right was longer",
         ):
             check_iterables_equal([9], [1, 2, 3])
 
     def test_error_differing_items_and_same_length(self) -> None:
         with raises(
             CheckIterablesEqualError,
-            match="Iterables .* and .* must be equal; differing items were .*",
+            match=r"Iterables .* and .* must be equal; differing items were .*",
         ):
             check_iterables_equal([1, 2, 3], [1, 2, 9])
 
     def test_error_no_differing_items_just_left_longer(self) -> None:
         with raises(
             CheckIterablesEqualError,
-            match="Iterables .* and .* must be equal; left was longer",
+            match=r"Iterables .* and .* must be equal; left was longer",
         ):
             check_iterables_equal([1, 2, 3], [1])
 
     def test_error_no_differing_items_just_right_longer(self) -> None:
         with raises(
             CheckIterablesEqualError,
-            match="Iterables .* and .* must be equal; right was longer",
+            match=r"Iterables .* and .* must be equal; right was longer",
         ):
             check_iterables_equal([1], [1, 2, 3])
 
@@ -348,7 +348,7 @@ class TestCheckLength:
 
     def test_min_error(self) -> None:
         with raises(
-            CheckLengthError, match="Object .* must have minimum length .*; got .*"
+            CheckLengthError, match=r"Object .* must have minimum length .*; got .*"
         ):
             check_length([], min=1)
 
@@ -357,7 +357,7 @@ class TestCheckLength:
 
     def test_max_error(self) -> None:
         with raises(
-            CheckLengthError, match="Object .* must have maximum length .*; got .*"
+            CheckLengthError, match=r"Object .* must have maximum length .*; got .*"
         ):
             check_length([1], max=0)
 
@@ -369,7 +369,7 @@ class TestCheckLengthsEqual:
     def test_error(self) -> None:
         with raises(
             CheckLengthsEqualError,
-            match="Sized objects .* and .* must have the same length; got .* and .*",
+            match=r"Sized objects .* and .* must have the same length; got .* and .*",
         ):
             check_lengths_equal([], [1, 2, 3])
 
@@ -381,49 +381,49 @@ class TestCheckMappingsEqual:
     def test_error_extra_and_missing_and_differing_values(self) -> None:
         with raises(
             CheckMappingsEqualError,
-            match="Mappings .* and .* must be equal; left had extra keys .*, right had extra keys .* and differing values were .*",
+            match=r"Mappings .* and .* must be equal; left had extra keys .*, right had extra keys .* and differing values were .*",
         ):
             check_mappings_equal({"a": 1, "b": 2, "c": 3}, {"b": 2, "c": 9, "d": 4})
 
     def test_error_extra_and_missing(self) -> None:
         with raises(
             CheckMappingsEqualError,
-            match="Mappings .* and .* must be equal; left had extra keys .* and right had extra keys .*",
+            match=r"Mappings .* and .* must be equal; left had extra keys .* and right had extra keys .*",
         ):
             check_mappings_equal({"a": 1, "b": 2, "c": 3}, {"b": 2, "c": 3, "d": 4})
 
     def test_error_extra_and_differing_values(self) -> None:
         with raises(
             CheckMappingsEqualError,
-            match="Mappings .* and .* must be equal; left had extra keys .* and differing values were .*",
+            match=r"Mappings .* and .* must be equal; left had extra keys .* and differing values were .*",
         ):
             check_mappings_equal({"a": 1, "b": 2, "c": 3}, {"a": 9})
 
     def test_error_missing_and_differing_values(self) -> None:
         with raises(
             CheckMappingsEqualError,
-            match="Mappings .* and .* must be equal; right had extra keys .* and differing values were .*",
+            match=r"Mappings .* and .* must be equal; right had extra keys .* and differing values were .*",
         ):
             check_mappings_equal({"a": 1}, {"a": 9, "b": 2, "c": 3})
 
     def test_error_extra_only(self) -> None:
         with raises(
             CheckMappingsEqualError,
-            match="Mappings .* and .* must be equal; left had extra keys .*",
+            match=r"Mappings .* and .* must be equal; left had extra keys .*",
         ):
             check_mappings_equal({"a": 1, "b": 2, "c": 3}, {"a": 1})
 
     def test_error_missing_only(self) -> None:
         with raises(
             CheckMappingsEqualError,
-            match="Mappings .* and .* must be equal; right had extra keys .*",
+            match=r"Mappings .* and .* must be equal; right had extra keys .*",
         ):
             check_mappings_equal({"a": 1}, {"a": 1, "b": 2, "c": 3})
 
     def test_error_differing_values_only(self) -> None:
         with raises(
             CheckMappingsEqualError,
-            match="Mappings .* and .* must be equal; differing values were .*",
+            match=r"Mappings .* and .* must be equal; differing values were .*",
         ):
             check_mappings_equal({"a": 1, "b": 2, "c": 3}, {"a": 1, "b": 2, "c": 9})
 
@@ -438,21 +438,21 @@ class TestCheckSetsEqual:
     def test_error_extra_and_missing(self) -> None:
         with raises(
             CheckSetsEqualError,
-            match="Sets .* and .* must be equal; left had extra items .* and right had extra items .*",
+            match=r"Sets .* and .* must be equal; left had extra items .* and right had extra items .*",
         ):
             check_sets_equal({1, 2, 3}, {2, 3, 4})
 
     def test_error_extra(self) -> None:
         with raises(
             CheckSetsEqualError,
-            match="Sets .* and .* must be equal; left had extra items .*",
+            match=r"Sets .* and .* must be equal; left had extra items .*",
         ):
             check_sets_equal({1, 2, 3}, set())
 
     def test_error_missing(self) -> None:
         with raises(
             CheckSetsEqualError,
-            match="Sets .* and .* must be equal; right had extra items .*",
+            match=r"Sets .* and .* must be equal; right had extra items .*",
         ):
             check_sets_equal(set(), {1, 2, 3})
 
@@ -464,21 +464,21 @@ class TestCheckSubMapping:
     def test_error_extra_and_differing_values(self) -> None:
         with raises(
             CheckSubMappingError,
-            match="Mapping .* must be a submapping of .*; left had extra keys .* and differing values were .*",
+            match=r"Mapping .* must be a submapping of .*; left had extra keys .* and differing values were .*",
         ):
             check_submapping({"a": 1, "b": 2, "c": 3}, {"a": 9})
 
     def test_error_extra_only(self) -> None:
         with raises(
             CheckSubMappingError,
-            match="Mapping .* must be a submapping of .*; left had extra keys .*",
+            match=r"Mapping .* must be a submapping of .*; left had extra keys .*",
         ):
             check_submapping({"a": 1, "b": 2, "c": 3}, {"a": 1})
 
     def test_error_differing_values_only(self) -> None:
         with raises(
             CheckSubMappingError,
-            match="Mapping .* must be a submapping of .*; differing values were .*",
+            match=r"Mapping .* must be a submapping of .*; differing values were .*",
         ):
             check_submapping({"a": 1, "b": 2, "c": 3}, {"a": 1, "b": 2, "c": 9})
 
@@ -493,7 +493,7 @@ class TestCheckSubSet:
     def test_error(self) -> None:
         with raises(
             CheckSubSetError,
-            match="Set .* must be a subset of .*; left had extra items .*",
+            match=r"Set .* must be a subset of .*; left had extra items .*",
         ):
             check_subset({1, 2, 3}, {1})
 
@@ -505,21 +505,21 @@ class TestCheckSuperMapping:
     def test_error_missing_and_differing_values(self) -> None:
         with raises(
             CheckSuperMappingError,
-            match="Mapping .* must be a supermapping of .*; right had extra keys .* and differing values were .*",
+            match=r"Mapping .* must be a supermapping of .*; right had extra keys .* and differing values were .*",
         ):
             check_supermapping({"a": 1}, {"a": 9, "b": 2, "c": 3})
 
     def test_error_extra_only(self) -> None:
         with raises(
             CheckSuperMappingError,
-            match="Mapping .* must be a supermapping of .*; right had extra keys .*",
+            match=r"Mapping .* must be a supermapping of .*; right had extra keys .*",
         ):
             check_supermapping({"a": 1}, {"a": 1, "b": 2, "c": 3})
 
     def test_error_differing_values_only(self) -> None:
         with raises(
             CheckSuperMappingError,
-            match="Mapping .* must be a supermapping of .*; differing values were .*",
+            match=r"Mapping .* must be a supermapping of .*; differing values were .*",
         ):
             check_supermapping({"a": 1, "b": 2, "c": 3}, {"a": 1, "b": 2, "c": 9})
 
@@ -575,7 +575,7 @@ class TestChunked:
         ],
     )
     def test_main(
-        self, *, iterable: Iterable[str], expected: Sequence[Sequence[str]]
+        self, *, iterable: Iterable[str], expected: Sequence[list[str]]
     ) -> None:
         result = list(chunked(iterable, 3))
         assert result == expected
@@ -614,7 +614,7 @@ class TestEnsureIterable:
         _ = ensure_iterable(obj)
 
     def test_error(self) -> None:
-        with raises(EnsureIterableError, match="Object .* must be iterable"):
+        with raises(EnsureIterableError, match=r"Object .* must be iterable"):
             _ = ensure_iterable(None)
 
 
@@ -627,7 +627,7 @@ class TestEnsureIterableNotStr:
     def test_error(self, *, obj: Any) -> None:
         with raises(
             EnsureIterableNotStrError,
-            match="Object .* must be iterable, but not a string",
+            match=r"Object .* must be iterable, but not a string",
         ):
             _ = ensure_iterable_not_str(obj)
 
@@ -885,11 +885,13 @@ class TestMergeStrMappings:
 
 
 class TestOne:
-    @given(args=sampled_from([([None],), ([None], []), ([None], [], [])]))
+    @mark.parametrize(
+        "args", [param(([None],)), param(([None], [])), param(([None], [], []))]
+    )
     def test_main(self, *, args: tuple[Iterable[Any], ...]) -> None:
         assert one(*args) is None
 
-    @given(args=sampled_from([([],), ([], []), ([], [], [])]))
+    @mark.parametrize("args", [param([]), param(([], [])), param(([], [], []))])
     def test_error_empty(self, *, args: tuple[Iterable[Any], ...]) -> None:
         with raises(OneEmptyError, match=r"Iterable\(s\) .* must not be empty"):
             _ = one(*args)
@@ -907,20 +909,21 @@ class TestOne:
 
 
 class TestOneMaybe:
-    @given(
-        args=sampled_from([
-            (None,),
-            ([None],),
-            (None, []),
-            ([None], []),
-            (None, []),
-            ([None], [], []),
-        ])
+    @mark.parametrize(
+        "args",
+        [
+            param((None,)),
+            param(([None],)),
+            param((None, [])),
+            param(([None], [])),
+            param((None, [], [])),
+            param(([None], [], [])),
+        ],
     )
     def test_main(self, *, args: tuple[MaybeIterable[Any], ...]) -> None:
         assert one_maybe(*args) is None
 
-    @given(args=sampled_from([([],), ([], []), ([], [], [])]))
+    @mark.parametrize("args", [param([]), param(([], [])), param(([], [], []))])
     def test_error_empty(self, *, args: tuple[MaybeIterable[Any], ...]) -> None:
         with raises(OneMaybeEmptyError, match=r"Object\(s\) must not be empty"):
             _ = one_maybe(*args)
@@ -1095,7 +1098,7 @@ class TestRangePartitions:
         assert result == expected
 
     def test_error_stop(self) -> None:
-        with raises(_RangePartitionsStopError, match="'stop' must be positive; got 0"):
+        with raises(_RangePartitionsStopError, match=r"'stop' must be positive; got 0"):
             _ = range_partitions(0, 0, 0)
 
     def test_error_total_too_low(self) -> None:
@@ -1175,7 +1178,7 @@ class TestResolveIncludeAndExclude:
     def test_error(self) -> None:
         with raises(
             ResolveIncludeAndExcludeError,
-            match="Iterables .* and .* must not overlap; got .*",
+            match=r"Iterables .* and .* must not overlap; got .*",
         ):
             _ = resolve_include_and_exclude(include=[1, 2, 3], exclude=[3, 4, 5])
 
@@ -1226,7 +1229,7 @@ class TestSortIterable:
         assert result1 == result2
 
     def test_error(self) -> None:
-        with raises(SortIterableError, match="Unable to sort .* and .*"):
+        with raises(SortIterableError, match=r"Unable to sort .* and .*"):
             _ = sort_iterable([sentinel, sentinel])
 
 
