@@ -251,7 +251,7 @@ class TestGetLoggingLevelNumber:
 
     def test_error(self) -> None:
         with raises(
-            GetLoggingLevelNumberError, match="Invalid logging level: 'invalid'"
+            GetLoggingLevelNumberError, match=r"Invalid logging level: 'invalid'"
         ):
             _ = get_logging_level_number(cast("Any", "invalid"))
 
@@ -449,10 +449,12 @@ class TestSizeAndTimeRotatingFileHandler:
             )
         )
 
+        await sleep(0.1)
         files = list(tmp_path.iterdir())
         assert len(files) == 1
         assert any(p for p in files if search(r"^log\.txt$", p.name))
 
+        await sleep(0.1)
         logger.warning("message 1")
         files = list(tmp_path.iterdir())
         assert len(files) == 1
