@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 from os import getenv
+from typing import TYPE_CHECKING
 
 from hypothesis import given
 from hypothesis.strategies import (
@@ -16,10 +17,14 @@ from pytest import mark, param, raises
 from utilities.hypothesis import text_ascii
 from utilities.os import (
     CPU_COUNT,
+    EFFECTIVE_GROUP_ID,
+    EFFECTIVE_USER_ID,
     GetCPUUseError,
     GetEnvVarError,
     get_cpu_count,
     get_cpu_use,
+    get_effective_group_id,
+    get_effective_user_id,
     get_env_var,
     is_debug,
     is_pytest,
@@ -27,6 +32,9 @@ from utilities.os import (
 )
 from utilities.pytest import skipif_windows
 
+if TYPE_CHECKING:
+    from collections.abc import Callable
+
 text = text_ascii(min_size=1, max_size=10)
 
 
@@ -59,6 +67,19 @@ class TestGetCPUUse:
             _ = get_cpu_use(n=n)
 
 
+class TestGetEffectiveIDs:
+    @mark.parametrize(
+        "func", [param(get_effective_user_id), param(get_effective_group_id)]
+    )
+    def test_function(self, *, func: Callable[[], int | None]) -> None:
+        id_ = func()
+        assert isinstance(id_, int) or (id_ is None)
+
+    @mark.parametrize("id_", [param(EFFECTIVE_USER_ID), param(EFFECTIVE_GROUP_ID)])
+    def test_constant(self, *, id_: int | None) -> None:
+        assert isinstance(id_, int) or (id_ is None)
+
+
 class TestGetEnvVar:
     @given(
         key=text.map(_prefix), value=text, default=text | none(), nullable=booleans()
@@ -134,6 +155,10 @@ class TestIsPytest:
     def test_main(self) -> None:
         assert is_pytest()
 
+    def test_off(self) -> None:
+        with temp_environ(PYTEST_VERSION=None):
+            assert not is_pytest()
+
 
 class TestTempEnviron:
     @given(key=text.map(_prefix), value=text)
