@@ -28,6 +28,7 @@ from utilities.text import (
     _SplitStrCountError,
     _SplitStrOpeningBracketUnmatchedError,
     join_strs,
+    kebab_case,
     parse_bool,
     parse_none,
     pascal_case,
@@ -85,7 +86,7 @@ class TestParseBool:
         ],
     )
     def test_error(self, *, text: str) -> None:
-        with raises(ParseBoolError, match="Unable to parse boolean value; got '.*'"):
+        with raises(ParseBoolError, match=r"Unable to parse boolean value; got '.*'"):
             _ = parse_bool(text)
 
 
@@ -99,7 +100,7 @@ class TestParseNone:
 
     @mark.parametrize("text", [param("invalid"), param("nnonee")])
     def test_error(self, *, text: str) -> None:
-        with raises(ParseNoneError, match="Unable to parse null value; got '.*'"):
+        with raises(ParseNoneError, match=r"Unable to parse null value; got '.*'"):
             _ = parse_none(text)
 
 
@@ -111,60 +112,86 @@ class TestReprEncode:
         assert result == expected
 
 
-class TestPascalAndSnakeCase:
+class TestPascalSnakeAndKebabCase:
     @mark.parametrize(
-        ("text", "exp_pascal", "exp_snake"),
+        ("text", "exp_pascal", "exp_snake", "exp_kebab"),
         [
-            param("API", "API", "api"),
-            param("APIResponse", "APIResponse", "api_response"),
+            param("API", "API", "api", "api"),
+            param("APIResponse", "APIResponse", "api_response", "api-response"),
             param(
                 "ApplicationController",
                 "ApplicationController",
                 "application_controller",
+                "application-controller",
             ),
-            param("Area51Controller", "Area51Controller", "area51_controller"),
-            param("FreeBSD", "FreeBSD", "free_bsd"),
-            param("HTML", "HTML", "html"),
-            param("HTMLTidy", "HTMLTidy", "html_tidy"),
-            param("HTMLTidyGenerator", "HTMLTidyGenerator", "html_tidy_generator"),
-            param("HTMLVersion", "HTMLVersion", "html_version"),
-            param("NoHTML", "NoHTML", "no_html"),
-            param("One   Two", "OneTwo", "one_two"),
-            param("One  Two", "OneTwo", "one_two"),
-            param("One Two", "OneTwo", "one_two"),
-            param("OneTwo", "OneTwo", "one_two"),
-            param("One_Two", "OneTwo", "one_two"),
-            param("One__Two", "OneTwo", "one_two"),
-            param("One___Two", "OneTwo", "one_two"),
-            param("Product", "Product", "product"),
-            param("SpecialGuest", "SpecialGuest", "special_guest"),
-            param("Text", "Text", "text"),
-            param("Text123", "Text123", "text123"),
-            param("Text123Text456", "Text123Text456", "text123_text456"),
-            param("_APIResponse_", "APIResponse", "_api_response_"),
-            param("_API_", "API", "_api_"),
-            param("__APIResponse__", "APIResponse", "_api_response_"),
-            param("__API__", "API", "_api_"),
-            param("__impliedVolatility_", "ImpliedVolatility", "_implied_volatility_"),
-            param("_itemID", "ItemID", "_item_id"),
-            param("_lastPrice__", "LastPrice", "_last_price_"),
-            param("_symbol", "Symbol", "_symbol"),
-            param("aB", "AB", "a_b"),
-            param("changePct", "ChangePct", "change_pct"),
-            param("changePct_", "ChangePct", "change_pct_"),
-            param("impliedVolatility", "ImpliedVolatility", "implied_volatility"),
-            param("lastPrice", "LastPrice", "last_price"),
-            param("memMB", "MemMB", "mem_mb"),
-            param("sizeX", "SizeX", "size_x"),
-            param("symbol", "Symbol", "symbol"),
-            param("testNTest", "TestNTest", "test_n_test"),
-            param("text", "Text", "text"),
-            param("text123", "Text123", "text123"),
+            param(
+                "Area51Controller",
+                "Area51Controller",
+                "area51_controller",
+                "area51-controller",
+            ),
+            param("FreeBSD", "FreeBSD", "free_bsd", "free-bsd"),
+            param("HTML", "HTML", "html", "html"),
+            param("HTMLTidy", "HTMLTidy", "html_tidy", "html-tidy"),
+            param(
+                "HTMLTidyGenerator",
+                "HTMLTidyGenerator",
+                "html_tidy_generator",
+                "html-tidy-generator",
+            ),
+            param("HTMLVersion", "HTMLVersion", "html_version", "html-version"),
+            param("NoHTML", "NoHTML", "no_html", "no-html"),
+            param("One   Two", "OneTwo", "one_two", "one-two"),
+            param("One  Two", "OneTwo", "one_two", "one-two"),
+            param("One Two", "OneTwo", "one_two", "one-two"),
+            param("OneTwo", "OneTwo", "one_two", "one-two"),
+            param("One_Two", "OneTwo", "one_two", "one-two"),
+            param("One__Two", "OneTwo", "one_two", "one-two"),
+            param("One___Two", "OneTwo", "one_two", "one-two"),
+            param("Product", "Product", "product", "product"),
+            param("SpecialGuest", "SpecialGuest", "special_guest", "special-guest"),
+            param("Text", "Text", "text", "text"),
+            param("Text123", "Text123", "text123", "text123"),
+            param(
+                "Text123Text456", "Text123Text456", "text123_text456", "text123-text456"
+            ),
+            param("_APIResponse_", "APIResponse", "_api_response_", "-api-response-"),
+            param("_API_", "API", "_api_", "-api-"),
+            param("__APIResponse__", "APIResponse", "_api_response_", "-api-response-"),
+            param("__API__", "API", "_api_", "-api-"),
+            param(
+                "__impliedVolatility_",
+                "ImpliedVolatility",
+                "_implied_volatility_",
+                "-implied-volatility-",
+            ),
+            param("_itemID", "ItemID", "_item_id", "-item-id"),
+            param("_lastPrice__", "LastPrice", "_last_price_", "-last-price-"),
+            param("_symbol", "Symbol", "_symbol", "-symbol"),
+            param("aB", "AB", "a_b", "a-b"),
+            param("changePct", "ChangePct", "change_pct", "change-pct"),
+            param("changePct_", "ChangePct", "change_pct_", "change-pct-"),
+            param(
+                "impliedVolatility",
+                "ImpliedVolatility",
+                "implied_volatility",
+                "implied-volatility",
+            ),
+            param("lastPrice", "LastPrice", "last_price", "last-price"),
+            param("memMB", "MemMB", "mem_mb", "mem-mb"),
+            param("sizeX", "SizeX", "size_x", "size-x"),
+            param("symbol", "Symbol", "symbol", "symbol"),
+            param("testNTest", "TestNTest", "test_n_test", "test-n-test"),
+            param("text", "Text", "text", "text"),
+            param("text123", "Text123", "text123", "text123"),
         ],
     )
-    def test_main(self, *, text: str, exp_pascal: str, exp_snake: str) -> None:
+    def test_main(
+        self, *, text: str, exp_pascal: str, exp_snake: str, exp_kebab: str
+    ) -> None:
         assert pascal_case(text) == exp_pascal
         assert snake_case(text) == exp_snake
+        assert kebab_case(text) == exp_kebab
 
 
 class TestPromptBool:
@@ -241,15 +268,15 @@ class TestSplitAndJoinStr:
     @mark.parametrize(
         ("text", "n", "expected"),
         [
-            param("", 0, []),
-            param(r"\,", 1, [""]),
-            param(",", 2, ["", ""]),
-            param(",,", 3, ["", "", ""]),
-            param("1", 1, ["1"]),
-            param("1,22", 2, ["1", "22"]),
-            param("1,22,333", 3, ["1", "22", "333"]),
-            param("1,,333", 3, ["1", "", "333"]),
-            param("1,(22,22,22),333", 5, ["1", "(22", "22", "22)", "333"]),
+            param("", 0, ()),
+            param(r"\,", 1, ("",)),
+            param(",", 2, ("", "")),
+            param(",,", 3, ("", "", "")),
+            param("1", 1, ("1",)),
+            param("1,22", 2, ("1", "22")),
+            param("1,22,333", 3, ("1", "22", "333")),
+            param("1,,333", 3, ("1", "", "333")),
+            param("1,(22,22,22),333", 5, ("1", "(22", "22", "22)", "333")),
         ],
     )
     def test_main(
@@ -267,12 +294,12 @@ class TestSplitAndJoinStr:
     @mark.parametrize(
         ("text", "n", "expected"),
         [
-            param("1", 1, ["1"]),
-            param("1,22", 2, ["1", "22"]),
-            param("1,22,333", 3, ["1", "22", "333"]),
-            param("1,(22),333", 3, ["1", "(22)", "333"]),
-            param("1,(22,22),333", 3, ["1", "(22,22)", "333"]),
-            param("1,(22,22,22),333", 3, ["1", "(22,22,22)", "333"]),
+            param("1", 1, ("1",)),
+            param("1,22", 2, ("1", "22")),
+            param("1,22,333", 3, ("1", "22", "333")),
+            param("1,(22),333", 3, ("1", "(22)", "333")),
+            param("1,(22,22),333", 3, ("1", "(22,22)", "333")),
+            param("1,(22,22,22),333", 3, ("1", "(22,22,22)", "333")),
         ],
     )
     def test_brackets(
@@ -286,13 +313,13 @@ class TestSplitAndJoinStr:
             assert result == tuple(expected)
         assert join_strs(result) == text
 
-    @given(texts=lists(text_ascii()))
-    def test_generic(self, *, texts: list[str]) -> None:
+    @given(texts=lists(text_ascii()).map(tuple))
+    def test_generic(self, *, texts: tuple[str, ...]) -> None:
         assert split_str(join_strs(texts)) == texts
 
     @given(texts=sets(text_ascii()))
     def test_sort(self, *, texts: set[str]) -> None:
-        assert split_str(join_strs(texts, sort=True)) == sorted(texts)
+        assert split_str(join_strs(texts, sort=True)) == tuple(sorted(texts))
 
     def test_error_closing_bracket_mismatched(self) -> None:
         with raises(
