@@ -847,13 +847,9 @@ def paths(
 ) -> Path:
     """Strategy for generating `Path`s."""
     min_depth_, max_depth_ = [draw2(draw, d) for d in [min_depth, max_depth]]
-    parts = draw(
-        lists(
-            _path_parts(),
-            min_size=0 if min_depth_ is None else min_depth_,
-            max_size=max_depth_,
-        )
-    )
+    min_depth_ = max_nullable([min_depth_, 0])
+    max_depth_ = min_nullable([max_depth_, 10])
+    parts = draw(lists(_path_parts(), min_size=min_depth_, max_size=max_depth_))
     return Path(*parts)
 
 
@@ -1574,10 +1570,10 @@ def zoned_date_times(
     with (
         assume_does_not_raise(RepeatedTime),
         assume_does_not_raise(SkippedTime),
-        assume_does_not_raise(ValueError, match="Resulting datetime is out of range"),
+        assume_does_not_raise(ValueError, match=r"Resulting time is out of range"),
     ):
         zoned = plain.assume_tz(time_zone_.key, disambiguate="raise")
-    with assume_does_not_raise(OverflowError, match="date value out of range"):
+    with assume_does_not_raise(OverflowError, match=r"date value out of range"):
         if not ((Date.MIN + DAY) <= zoned.date() <= (Date.MAX - DAY)):
             _ = zoned.py_datetime()
     return zoned
