@@ -8,7 +8,7 @@ from pyinstrument.profiler import Profiler
 
 from utilities.atomicwrites import writer
 from utilities.pathlib import to_path
-from utilities.whenever import get_now, to_local_plain
+from utilities.whenever import format_compact, get_now_local
 
 if TYPE_CHECKING:
     from collections.abc import Iterator
@@ -21,7 +21,9 @@ def profile(path: MaybeCallablePathLike = Path.cwd, /) -> Iterator[None]:
     """Profile the contents of a block."""
     with Profiler() as profiler:
         yield
-    filename = to_path(path).joinpath(f"profile__{to_local_plain(get_now())}.html")
+    filename = to_path(path).joinpath(
+        f"profile__{format_compact(get_now_local(), path=True)}.html"
+    )
     with writer(filename) as temp:
         _ = temp.write_text(profiler.output_html())
 
