@@ -37,7 +37,7 @@ from utilities.whenever import (
 )
 
 if TYPE_CHECKING:
-    from collections.abc import Callable, Iterator, Sequence
+    from collections.abc import Callable, Iterator
     from traceback import FrameSummary
     from types import TracebackType
 
@@ -70,7 +70,7 @@ def format_exception_stack(
     expand_all: bool = RICH_EXPAND_ALL,
 ) -> str:
     """Format an exception stack."""
-    lines: Sequence[str] = []
+    lines: list[str] = []
     if header:
         lines.extend(_yield_header_lines(start=start, version=version))
     lines.extend(
@@ -98,7 +98,7 @@ def _yield_header_lines(
     yield f"Date/time  | {format_compact(now)}"
     start_use = to_zoned_date_time(start).to_tz(LOCAL_TIME_ZONE_NAME)
     yield f"Started    | {format_compact(start_use)}"
-    yield f"Duration   | {(now - start_use).format_common_iso()}"
+    yield f"Duration   | {(now - start_use).format_iso()}"
     yield f"User       | {getuser()}"
     yield f"Host       | {gethostname()}"
     yield f"Process ID | {getpid()}"
